<?php
namespace Elementor;

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit;   
}

// Class Item Lists
class Item_Lists_Pro_Elementor_Widget extends Widget_Base {

    // Function for get the slug of the element name.
    public function get_name() {
        return 'ile-item-lists-elementor-widget';
    }

    // Function for get the name of the element.
    public function get_title() {
        return esc_html__('Item Lists', ILPE_DOMAIN);
    }

    // Function for get the icon of the element.
    public function get_icon() {
        return 'eicon-bullet-list';
    }

    // Function for include element into the category.
    public function get_categories() {
        return ['item-lists'];
    }

    // Function for include element keywords.
    public function get_keywords() {
        return ['item list', 'icon list', 'bullet list'];
	}

    // Adding the controls fields for the Item Lists Element
    protected function _register_controls() {

        // Start Item Lists General Section
        $this->start_controls_section(
            'section_general', array(
                'label'         => esc_html__('General', ILPE_DOMAIN),
            )
        );

        $this->add_control(
            'item_lists_style', [
                'label'         => esc_html__('List Style', ILPE_DOMAIN),
                'type'          => Controls_Manager::SELECT,
                'options'       => [
                    'material-bullet-style'             => esc_html__('Material Item list', ILPE_DOMAIN),
                    'shape-bullet-style'                => esc_html__('Shape Item list', ILPE_DOMAIN),
                    'timeline-bullet-style'             => esc_html__('Timeline Item list', ILPE_DOMAIN),
                    'alternate-timeline-bullet-style'   => esc_html__('Alternate Timeline Item list', ILPE_DOMAIN),
                    'gradient-ordered-bullet-style'     => esc_html__('Gradient Ordered Item list', ILPE_DOMAIN),
                    'skew-bullet-style'                 => esc_html__('Skew Bullets', ILPE_DOMAIN),
                    'service-bullet-style'              => esc_html__('Service Bullets', ILPE_DOMAIN),
                    'gradient-service-bullet-style'     => esc_html__('Gradient Service Bullets', ILPE_DOMAIN),
					'material-curve-bullet-style'     	=> esc_html__('Material Curve Bullets', ILPE_DOMAIN),
					'material-angle-bullet-style'     	=> esc_html__('Material Angle Bullets', ILPE_DOMAIN),
                ],
                'default'       => 'material-bullet-style',
            ]
        );

        $this->end_controls_section();
        // End Item Lists General Section

        // Start Item Lists Items Section
        // Material Bullet Style Items
        $this->start_controls_section(
            'section_material_list_items', array(
                'label'         => esc_html__('Items', ILPE_DOMAIN),
                'condition'     => [
                    'item_lists_style'  => 'material-bullet-style',
                ],
            )
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'material_list_items_title',
            [
                'label'         => esc_html__('Title', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__('Title', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'material_list_items_content',
            [
                'label'         => esc_html__('Content', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXTAREA,
                'default'       => esc_html__('Lorem ipsum dolor sit amet, consectetur adipisi cing elit, sed do eiusmod tempor incididunt ut abore et dolore magna', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'material_list_items_display_icon',
            [
                'label'         => esc_html__('Icon', ILPE_DOMAIN),
                'type'          => Controls_Manager::CHOOSE,
                'options'       => [
                    'none'  => [
                        'title' => esc_html__('None', ILPE_DOMAIN),
                        'icon'  => 'fa fa-ban',
                    ],
                    'icon'  => [
                        'title' => esc_html__('Icon', ILPE_DOMAIN),
                        'icon'  => 'fa fa-info-circle',
                    ],
                    'image'  => [
                        'title' => esc_html__('Image', ILPE_DOMAIN),
                        'icon'  => 'fas fa-image',
                    ],
                ],
                'default'       => 'icon',
            ]
        );

        $repeater->add_control(
			'material_list_items_image',
			[
				'type'          => Controls_Manager::MEDIA,
				'default'       => [
					'url'       => Utils::get_placeholder_image_src(),
				],
                'condition'     => [
                    'material_list_items_display_icon'   => 'image',
                ],
			]
		);

        $repeater->add_control(
            'material_list_items_icon',
            [
                'type'          => Controls_Manager::ICONS,
                'default'       => [
                    'value'     => 'fas fa-leaf',
                    'library'   => 'fa-solid',
                ],
                'condition'     => [
                    'material_list_items_display_icon'   => 'icon',
                ],
            ]
        );

        $repeater->add_control(
            'material_icon_color', [
                'label'         => esc_html__('Icon Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#ffffff',
                'condition'     => [
                    'material_list_items_display_icon'   => 'icon',
                ],
            ]
        );

        $repeater->add_control(
            'material_icon_bg_color', [
                'label'         => esc_html__('Icon Background Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#ff8181',
                'condition'     => [
                    'material_list_items_display_icon'   => 'icon',
                ],
            ]
        );

        $repeater->add_control(
            'material_title_color', [
                'label'         => esc_html__('Title Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#ffffff',
            ]
        );

        $repeater->add_control(
            'material_content_color', [
                'label'         => esc_html__('Content Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#ffffff',
            ]
        );

        $repeater->add_control(
            'material_content_bg_color', [
                'label'         => esc_html__('Content Background Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#ec6161',
            ]
        );
        $repeater->add_control(
			'material_list_link',
			[
				'label' => esc_html__( 'Link', ILPE_DOMAIN ),
				'type' => Controls_Manager::URL,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'https://your-link.com', ILPE_DOMAIN ),
				'default' => [
					'url' => '#',
				],				
			]
		);

        $this->add_control(
			'material_item_lists',
			[
				'label'         => esc_html__('List Items', ILPE_DOMAIN),
                'type'          => Controls_Manager::REPEATER,
                'fields'        => $repeater->get_controls(),
                'render_type'   => 'template',
                'default'       => [
                    [
                        'material_list_items_title'         => esc_html__('List One', ILPE_DOMAIN), 
                        'material_content_bg_color'         => '#ec6161'
                    ],
                    [
                        'material_list_items_title'         => esc_html__('List Two', ILPE_DOMAIN),
                        'material_content_bg_color'         => '#2DCEC6',
                        'material_icon_bg_color'            => '#32DDD4',
                        'material_list_items_icon'          => [
                            'value'     => 'fas fa-laugh',
                            'library'   => 'fa-solid',
                        ],
                    ],
                    [
                        'material_list_items_title'         => esc_html__('List Three', ILPE_DOMAIN),
                        'material_content_bg_color'         => '#C56EE3',
                        'material_icon_bg_color'            => '#DB87F7',
                        'material_list_items_icon'          => [
                            'value'     => 'fas fa-paw',
                            'library'   => 'fa-solid',
                        ],
                    ],
                    [
                        'material_list_items_title'         => esc_html__('List Four', ILPE_DOMAIN),
                        'material_content_bg_color'         => '#868BFF',
                        'material_icon_bg_color'            => '#A8ADFF',
                        'material_list_items_icon'          => [
                            'value'     => 'fas fa-magnet',
                            'library'   => 'fa-solid',
                        ],
                    ],
                ],
                'title_field'   => '{{{ material_list_items_title }}}'
			]
        );

        $this->end_controls_section();

        // Shape Bullet Style Items
        $this->start_controls_section(
            'section_shape_list_items', array(
                'label'         => esc_html__('Items', ILPE_DOMAIN),
                'condition'     => [
                    'item_lists_style'      => 'shape-bullet-style',
                ],
            )
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'shape_list_items_title',
            [
                'label'         => esc_html__('Title', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__('Title', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'shape_list_items_content',
            [
                'label'         => esc_html__('Content', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXTAREA,
                'default'       => esc_html__('Lorem ipsum dolor sit amet, consectetur adipisi cing elit, sed do eiusmod tempor incididunt ut abore et dolore magna', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'shape_list_items_display_icon',
            [
                'label'         => esc_html__('Icon', ILPE_DOMAIN),
                'type'          => Controls_Manager::CHOOSE,
                'options'       => [
                    'none'  => [
                        'title' => esc_html__('None', ILPE_DOMAIN),
                        'icon'  => 'fa fa-ban',
                    ],
                    'icon'  => [
                        'title' => esc_html__('Icon', ILPE_DOMAIN),
                        'icon'  => 'fa fa-info-circle',
                    ],
                ],
                'default'       => 'icon',
            ]
        );

        $repeater->add_control(
            'shape_list_items_icon',
            [
                'type'          => Controls_Manager::ICONS,
                'default'       => [
                    'value'     => 'fas fa-leaf',
                    'library'   => 'fa-solid',
                ],
                'condition'     => [
                    'shape_list_items_display_icon'   => 'icon',
                ],
            ]
        );

        $repeater->add_control(
            'shape_list_item_icon_style', [
                'label'         => esc_html__('Icon Box Style', ILPE_DOMAIN),
                'type'          => Controls_Manager::SELECT,
                'options'       => [
                    'diamond-icon-style'        => esc_html__('Diamond', ILPE_DOMAIN),
                    'circle-icon-style'         => esc_html__('Circle', ILPE_DOMAIN),
                    'square-icon-style'         => esc_html__('Square', ILPE_DOMAIN),
                ],
                'default'       => 'diamond-icon-style',
            ]
        );

        $repeater->add_control(
			'shape_list_item_link',
			[
				'label' => esc_html__( 'Link', ILPE_DOMAIN ),
				'type' => Controls_Manager::URL,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'https://your-link.com', ILPE_DOMAIN ),
				'default' => [
					'url' => '#',
				],				
			]
		);

        $this->add_control(
			'shape_item_lists',
			[
				'label'         => esc_html__('List Items', ILPE_DOMAIN),
                'type'          => Controls_Manager::REPEATER,
                'fields'        => $repeater->get_controls(),
                'render_type'   => 'template',
                'default'       => [
                    [
                        'shape_list_items_title'      => esc_html__('List One', ILPE_DOMAIN),
                    ],
                    [
                        'shape_list_items_title'      => esc_html__('List Two', ILPE_DOMAIN),
                        'shape_list_item_icon_style'  => 'circle-icon-style',
                        'shape_list_items_icon'       => [
                            'value'     => 'fas fa-laugh',
                            'library'   => 'fa-solid',
                        ],
                    ],
                    [
                        'shape_list_items_title'      => esc_html__('List Three', ILPE_DOMAIN),
                        'shape_list_item_icon_style'  => 'square-icon-style',
                        'shape_list_items_icon'       => [
                            'value'     => 'fas fa-paw',
                            'library'   => 'fa-solid',
                        ],
                    ],
                ],
                'title_field'   => '{{{ shape_list_items_title }}}'
			]
        );

        $this->end_controls_section();

        // Timeline Bullet & Alternate Timeline Bullet Style Items
        $this->start_controls_section(
            'section_timeline_list_items', array(
                'label'         => esc_html__('Items', ILPE_DOMAIN),
                'condition'     => [
                    'item_lists_style'      => [ 'timeline-bullet-style', 'alternate-timeline-bullet-style' ],
                ],
            )
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'timeline_list_items_title',
            [
                'label'         => esc_html__('Title', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__('Title', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'timeline_list_items_content',
            [
                'label'         => esc_html__('Content', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXTAREA,
                'default'       => esc_html__('Lorem ipsum dolor sit amet, consectetur adipisi cing elit, sed do eiusmod tempor incididunt ut abore et dolore magna', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'timeline_list_items_display_icon',
            [
                'label'         => esc_html__('Icon', ILPE_DOMAIN),
                'type'          => Controls_Manager::CHOOSE,
                'options'       => [
                    'none'  => [
                        'title' => esc_html__('None', ILPE_DOMAIN),
                        'icon'  => 'fa fa-ban',
                    ],
                    'icon'  => [
                        'title' => esc_html__('Icon', ILPE_DOMAIN),
                        'icon'  => 'fa fa-info-circle',
                    ],
                    'image'  => [
                        'title' => esc_html__('Image', ILPE_DOMAIN),
                        'icon'  => 'fas fa-image',
                    ],
                ],
                'default'       => 'icon',
            ]
        );

        $repeater->add_control(
			'timeline_list_items_image',
			[
				'type'          => Controls_Manager::MEDIA,
				'default'       => [
					'url'       => Utils::get_placeholder_image_src(),
				],
                'condition'     => [
                    'timeline_list_items_display_icon'   => 'image',
                ],
			]
		);

        $repeater->add_control(
            'timeline_list_items_icon',
            [
                'type'          => Controls_Manager::ICONS,
                'default'       => [
                    'value'     => 'fas fa-leaf',
                    'library'   => 'fa-solid',
                ],
                'condition'     => [
                    'timeline_list_items_display_icon'   => 'icon',
                ],
            ]
        );

        $repeater->add_control(
            'timeline_icon_color', [
                'label'         => esc_html__('Icon Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#ffffff',
                'condition'     => [
                    'timeline_list_items_display_icon'   => 'icon',
                ],
            ]
        );

        $repeater->add_control(
            'timeline_icon_bg_color', [
                'label'         => esc_html__('Icon Background Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#ff8181',
                'condition'     => [
                    'timeline_list_items_display_icon'   => 'icon',
                ],
            ]
        );

        $repeater->add_control(
			'timeline_link',
			[
				'label' => esc_html__( 'Link', ILPE_DOMAIN ),
				'type' => Controls_Manager::URL,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'https://your-link.com', ILPE_DOMAIN ),
				'default' => [
					'url' => '#',
				],				
			]
		);

        $this->add_control(
			'timeline_item_lists',
			[
				'label'         => esc_html__('List Items', ILPE_DOMAIN),
                'type'          => Controls_Manager::REPEATER,
                'fields'        => $repeater->get_controls(),
                'render_type'   => 'template',
                'default'       => [
                    [
                        'timeline_list_items_title'      => esc_html__('List One', ILPE_DOMAIN),
                    ],
                    [
                        'timeline_list_items_title'      => esc_html__('List Two', ILPE_DOMAIN),
                        'timeline_icon_bg_color'         => '#32DDD4',
                        'timeline_list_items_icon'       => [
                            'value'     => 'fas fa-laugh',
                            'library'   => 'fa-solid',
                        ],
                    ],
                    [
                        'timeline_list_items_title'      => esc_html__('List Three', ILPE_DOMAIN),
                        'timeline_icon_bg_color'         => '#DB87F7',
                        'timeline_list_items_icon'       => [
                            'value'     => 'fas fa-paw',
                            'library'   => 'fa-solid',
                        ],
                    ],
                    [
                        'timeline_list_items_title'      => esc_html__('List Four', ILPE_DOMAIN),
                        'timeline_icon_bg_color'         => '#A8ADFF',
                        'timeline_list_items_icon'       => [
                            'value'     => 'fas fa-magnet',
                            'library'   => 'fa-solid',
                        ],
                    ],
                ],
                'title_field'   => '{{{ timeline_list_items_title }}}'
			]
        );

        $this->end_controls_section();

        // Gradient Ordered Bullet Style Items
        $this->start_controls_section(
            'section_gradient_ordered_list_items', array(
                'label'         => esc_html__('Items', ILPE_DOMAIN),
                'condition'     => [
                    'item_lists_style'  => 'gradient-ordered-bullet-style',
                ],
            )
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'gradient_ordered_list_items_title',
            [
                'label'         => esc_html__('Title', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__('Title', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'gradient_ordered_list_items_content',
            [
                'label'         => esc_html__('Content', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXTAREA,
                'default'       => esc_html__('Lorem ipsum dolor sit amet, consectetur adipisi cing elit, sed do eiusmod tempor incididunt ut abore et dolore magna', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
			'gradient_ordered_list_items_link',
			[
				'label' => esc_html__( 'Link', ILPE_DOMAIN ),
				'type' => Controls_Manager::URL,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'https://your-link.com', ILPE_DOMAIN ),
				'default' => [
					'url' => '#',
				],				
			]
		);

        $this->add_control(
			'gradient_ordered_item_lists',
			[
				'label'         => esc_html__('List Items', ILPE_DOMAIN),
                'type'          => Controls_Manager::REPEATER,
                'fields'        => $repeater->get_controls(),
                'render_type'   => 'template',
                'default'       => [
                    [
                        'gradient_ordered_list_items_title'     => esc_html__('List One', ILPE_DOMAIN), 
                    ],
                    [
                        'gradient_ordered_list_items_title'     => esc_html__('List Two', ILPE_DOMAIN),
                    ],
                    [
                        'gradient_ordered_list_items_title'     => esc_html__('List Three', ILPE_DOMAIN),
                    ],
                    [
                        'gradient_ordered_list_items_title'     => esc_html__('List Four', ILPE_DOMAIN),
                    ],
                ],
                'title_field'   => '{{{ gradient_ordered_list_items_title }}}'
			]
        );

        $this->end_controls_section();

        // Skew Bullet Style Items
        $this->start_controls_section(
            'section_skew_list_items', array(
                'label'         => esc_html__('Items', ILPE_DOMAIN),
                'condition'     => [
                    'item_lists_style'  => 'skew-bullet-style',
                ],
            )
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'skew_list_items_title',
            [
                'label'         => esc_html__('Title', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__('Title', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'skew_list_items_content',
            [
                'label'         => esc_html__('Content', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXTAREA,
                'default'       => esc_html__('Lorem ipsum dolor sit amet, consectetur adipisi cing elit, sed do eiusmod tempor incididunt ut abore et dolore magna', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'skew_list_items_order',
            [
                'label'         => esc_html__('Order', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__('01', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'skew_list_items_icon',
            [
                'type'          => Controls_Manager::ICONS,
                'default'       => [
                    'value'     => 'fas fa-leaf',
                    'library'   => 'fa-solid',
                ],
            ]
        );

        $repeater->add_control(
            'skew_title_color', [
                'label'         => esc_html__('Title Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
            ]
        );

        $repeater->add_control(
            'skew_content_color', [
                'label'         => esc_html__('Content Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
            ]
        );

        $repeater->add_control(
            'skew_content_bg_color', [
                'label'         => esc_html__('Background Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#ffffff',
            ]
        );
        
        $repeater->add_control(
            'skew_content_border_color', [
                'label'         => esc_html__('Border Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#FF8181',
            ]
        );

        $repeater->add_control(
            'skew_icon_order_color', [
                'label'         => esc_html__('Icon & Order Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#ffffff',
            ]
        );

        $repeater->add_control(
            'skew_icon_order_bg_color', [
                'label'         => esc_html__('Icon & Order Background Color 1', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#EC6161',
            ]
        );

        $repeater->add_control(
            'skew_icon_order_bg_color_2', [
                'label'         => esc_html__('Icon & Order Background Color 2', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#FF8181',
            ]
        );
        
        $repeater->add_control(
			'skew_link',
			[
				'label' => esc_html__( 'Link', ILPE_DOMAIN ),
				'type' => Controls_Manager::URL,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'https://your-link.com', ILPE_DOMAIN ),
				'default' => [
					'url' => '#',
				],				
			]
		);

        $this->add_control(
			'skew_item_lists',
			[
				'label'         => esc_html__( 'List Items', ILPE_DOMAIN ),
                'type'          => Controls_Manager::REPEATER,
                'fields'        => $repeater->get_controls(),
                'render_type'   => 'template',
                'default'       => [
                    [
                        'skew_list_items_title'     => 'List One',
                    ],
                    [
                        'skew_list_items_title'     => 'List Two',
                        'skew_list_items_order'     => '02',
                        'skew_content_border_color'        => '#32DDD4',
                        'skew_icon_order_bg_color'        => '#2DCEC6',
                        'skew_icon_order_bg_color_2'        => '#32DDD4',
                        'skew_list_items_icon'      => [
                            'value'     => 'fas fa-laugh',
                            'library'   => 'fa-solid',
                        ],
                    ],
                    [
                        'skew_list_items_title'     => 'List Three',
                        'skew_list_items_order'     => '03',
                        'skew_content_border_color'        => '#DB87F7',
                        'skew_icon_order_bg_color'        => '#C56EE3',
                        'skew_icon_order_bg_color_2'        => '#DB87F7',
                        'skew_list_items_icon'       => [
                            'value'     => 'fas fa-paw',
                            'library'   => 'fa-solid',
                        ],
                    ],
                    [
                        'skew_list_items_title'     => 'List Four',
                        'skew_list_items_order'     => '04',
                        'skew_content_border_color'        => '#A8ADFF',
                        'skew_icon_order_bg_color'        => '#868BFF',
                        'skew_icon_order_bg_color_2'        => '#A8ADFF',
                        'skew_list_items_icon'       => [
                            'value'     => 'fas fa-magnet',
                            'library'   => 'fa-solid',
                        ],
                    ],
                ],
                'title_field'   => '{{{ skew_list_items_title }}}'
			]
        );

        $this->end_controls_section();

        // Service Bullet Style Items
        $this->start_controls_section(
            'section_service_list_items', array(
                'label'         => esc_html__('Items', ILPE_DOMAIN),
                'condition'     => [
                    'item_lists_style'      => [ 'service-bullet-style' ],
                ],
            )
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'service_list_items_title',
            [
                'label'         => esc_html__('Title', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__('Title', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'service_list_items_content',
            [
                'label'         => esc_html__('Content', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXTAREA,
                'default'       => esc_html__('Lorem ipsum dolor sit amet, consectetur adipisi cing elit, sed do eiusmod tempor incididunt ut abore et dolore magna', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'service_list_items_icon',
            [
                'type'          => Controls_Manager::ICONS,
                'default'       => [
                    'value'     => 'fas fa-leaf',
                    'library'   => 'fa-solid',
                ],
            ]
        );

        $repeater->add_control(
            'service_title_color', [
                'label'         => esc_html__('Title Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
            ]
        );

        $repeater->add_control(
            'service_content_color', [
                'label'         => esc_html__('Content Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
            ]
        );

        $repeater->add_control(
            'service_icon_color', [
                'label'         => esc_html__('Icon Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#000',
            ]
        );

        $repeater->add_control(
            'service_background_color', [
                'label'         => esc_html__('Background Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#fff',
            ]
        );

        $repeater->add_control(
            'service_background_overlay_color', [
                'label'         => esc_html__('Background Overlay Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#FF8181',
            ]
        );

        $repeater->add_control(
			'service_link',
			[
				'label' => esc_html__( 'Link', ILPE_DOMAIN ),
				'type' => Controls_Manager::URL,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'https://your-link.com', ILPE_DOMAIN ),
				'default' => [
					'url' => '#',
				],				
			]
		);

        $this->add_control(
            'service_item_lists',
            [
                'label'         => esc_html__( 'List Items', ILPE_DOMAIN ),
                'type'          => Controls_Manager::REPEATER,
                'fields'        => $repeater->get_controls(),
                'render_type'   => 'template',
                'default'       => [
                    [
                        'service_list_items_title'      => 'List One',
                    ],
                    [
                        'service_list_items_title'      => 'List Two',
                        'service_background_overlay_color'         => '#32DDD4',
                        'service_list_items_icon'       => [
                            'value'     => 'fas fa-laugh',
                            'library'   => 'fa-solid',
                        ],
                    ],
                    [
                        'service_list_items_title'      => 'List Three',
                        'service_background_overlay_color'         => '#DB87F7',
                        'service_list_items_icon'       => [
                            'value'     => 'fas fa-paw',
                            'library'   => 'fa-solid',
                        ],
                    ],
                    [
                        'service_list_items_title'      => 'List Four',
                        'service_background_overlay_color'         => '#A8ADFF',
                        'service_list_items_icon'       => [
                            'value'     => 'fas fa-magnet',
                            'library'   => 'fa-solid',
                        ],
                    ],
                ],
                'title_field'   => '{{{ service_list_items_title }}}'
            ]
        );

        $this->end_controls_section();

        // Gradient Service Bullet Style Items
        $this->start_controls_section(
            'section_gradient_service_list_items', array(
                'label'         => esc_html__('Items', ILPE_DOMAIN),
                'condition'     => [
                    'item_lists_style'      => [ 'gradient-service-bullet-style' ],
                ],
            )
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'gradient_service_list_items_title',
            [
                'label'         => esc_html__('Title', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__('Title', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'gradient_service_list_items_content',
            [
                'label'         => esc_html__('Content', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXTAREA,
                'default'       => esc_html__('Lorem ipsum dolor sit amet, consectetur adipisi cing elit, sed do eiusmod tempor incididunt ut abore et dolore magna', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'gradient_service_list_items_number',
            [
                'label'         => esc_html__('List Number', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__('1', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'gradient_service_list_items_icon',
            [
                'type'          => Controls_Manager::ICONS,
                'default'       => [
                    'value'     => 'fas fa-leaf',
                    'library'   => 'fa-solid',
                ],
            ]
        );

        $repeater->add_control(
            'gradient_service_title_color', [
                'label'         => esc_html__('Title Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
            ]
        );

        $repeater->add_control(
            'gradient_service_content_color', [
                'label'         => esc_html__('Content Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
            ]
        );

        $repeater->add_control(
            'gradient_service_content_bg_color', [
                'label'         => esc_html__('Content Background Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
            ]
        );

        $repeater->add_control(
            'gradient_service_icon_color', [
                'label'         => esc_html__('Icon Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#ffffff',
            ]
        );

        $repeater->add_control(
            'gradient_service_icon_bg_color_first', [
                'label'         => esc_html__('Icon Background Color 1', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#EC6161',
            ]
        );   

        $repeater->add_control(
            'gradient_service_icon_bg_color_second', [
                'label'         => esc_html__('Icon Background Color 2', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#FF8181',
            ]
        );

        $repeater->add_control(
			'gradient_service_link',
			[
				'label' => esc_html__( 'Link', ILPE_DOMAIN ),
				'type' => Controls_Manager::URL,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'https://your-link.com', ILPE_DOMAIN ),
				'default' => [
					'url' => '#',
				],				
			]
		);

        $this->add_control(
            'gradient_service_item_lists',
            [
                'label'         => esc_html__( 'List Items', ILPE_DOMAIN ),
                'type'          => Controls_Manager::REPEATER,
                'fields'        => $repeater->get_controls(),
                'render_type'   => 'template',
                'default'       => [
                    [
                        'gradient_service_list_items_title'      => 'List One',
                    ],
                    [
                        'gradient_service_list_items_title'      => 'List Two',
                        'gradient_service_icon_bg_color_first'   => '#2DCEC6',
                        'gradient_service_icon_bg_color_second'  => '#32DDD4',
                        'gradient_service_list_items_icon'       => [
                            'value'     => 'fas fa-laugh',
                            'library'   => 'fa-solid',
                        ],
                    ],
                    [
                        'gradient_service_list_items_title'      => 'List Three',
                        'gradient_service_icon_bg_color_first'   => '#C56EE3',
                        'gradient_service_icon_bg_color_second'  => '#DB87F7',
                        'gradient_service_list_items_icon'       => [
                            'value'     => 'fas fa-paw',
                            'library'   => 'fa-solid',
                        ],
                    ],
                    [
                        'gradient_service_list_items_title'      => 'List Four',
                        'gradient_service_icon_bg_color_first'   => '#868BFF',
                        'gradient_service_icon_bg_color_second'  => '#A8ADFF',
                        'gradient_service_list_items_icon'       => [
                            'value'     => 'fas fa-magnet',
                            'library'   => 'fa-solid',
                        ],
                    ],
                ],
                'title_field'   => '{{{ gradient_service_list_items_title }}}'
            ]
        );

        $this->end_controls_section();

        // Material Curve Bullet Style Items
        $this->start_controls_section(
            'section_material_curve_list_items', array(
                'label'         => esc_html__('Items', ILPE_DOMAIN),
                'condition'     => [
                    'item_lists_style'      => [ 'material-curve-bullet-style' ],
                ],
            )
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'material_curve_list_items_title',
            [
                'label'         => esc_html__('Title', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__('Title', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'material_curve_list_items_content',
            [
                'label'         => esc_html__('Content', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXTAREA,
                'default'       => esc_html__('Lorem ipsum dolor sit amet, consectetur adipisi cing elit, sed do eiusmod tempor incididunt ut abore et dolore magna', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'material_curve_list_items_icon',
            [
                'type'          => Controls_Manager::ICONS,
                'default'       => [
                    'value'     => 'fas fa-leaf',
                    'library'   => 'fa-solid',
                ],
            ]
        );

        $repeater->add_control(
            'material_curve_title_color', [
                'label'         => esc_html__('Title Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
            ]
        );

        $repeater->add_control(
            'material_curve_content_color', [
                'label'         => esc_html__('Content Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
            ]
        );

        $repeater->add_control(
            'material_curve_content_bg_color', [
                'label'         => esc_html__('Content Background Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
            ]
        );

        $repeater->add_control(
            'material_curve_icon_color', [
                'label'         => esc_html__('Icon Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#ffffff',
            ]
        );

        $repeater->add_control(
            'material_curve_icon_bg_color_first', [
                'label'         => esc_html__('Icon Background Color 1', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#EC6161',
            ]
        );   

        $repeater->add_control(
            'material_curve_icon_bg_color_second', [
                'label'         => esc_html__('Icon Background Color 2', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#FF8181',
            ]
        );

        $repeater->add_control(
			'material_curve_link',
			[
				'label' => esc_html__( 'Link', ILPE_DOMAIN ),
				'type' => Controls_Manager::URL,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'https://your-link.com', ILPE_DOMAIN ),
				'default' => [
					'url' => '#',
				],				
			]
		);

        $this->add_control(
            'material_curve_item_lists',
            [
                'label'         => esc_html__( 'List Items', ILPE_DOMAIN ),
                'type'          => Controls_Manager::REPEATER,
                'fields'        => $repeater->get_controls(),
                'render_type'   => 'template',
                'default'       => [
                    [
                        'material_curve_list_items_title'      => 'List One',
                    ],
                    [
                        'material_curve_list_items_title'      => 'List Two',
                        'material_curve_icon_bg_color_first'   => '#2DCEC6',
                        'material_curve_icon_bg_color_second'  => '#32DDD4',
                        'material_curve_list_items_icon'       => [
                            'value'     => 'fas fa-laugh',
                            'library'   => 'fa-solid',
                        ],
                    ],
                    [
                        'material_curve_list_items_title'      => 'List Three',
                        'material_curve_icon_bg_color_first'   => '#C56EE3',
                        'material_curve_icon_bg_color_second'  => '#DB87F7',
                        'material_curve_list_items_icon'       => [
                            'value'     => 'fas fa-paw',
                            'library'   => 'fa-solid',
                        ],
                    ],
                    [
                        'material_curve_list_items_title'      => 'List Four',
                        'material_curve_icon_bg_color_first'   => '#868BFF',
                        'material_curve_icon_bg_color_second'  => '#A8ADFF',
                        'material_curve_list_items_icon'       => [
                            'value'     => 'fas fa-magnet',
                            'library'   => 'fa-solid',
                        ],
                    ],
                ],
                'title_field'   => '{{{ material_curve_list_items_title }}}'
            ]
        );

        $this->end_controls_section();

        // Material Angle Bullet Style Items
        $this->start_controls_section(
            'section_material_angle_list_items', array(
                'label'         => esc_html__('Items', ILPE_DOMAIN),
                'condition'     => [
                    'item_lists_style'      => [ 'material-angle-bullet-style' ],
                ],
            )
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'material_angle_list_items_title',
            [
                'label'         => esc_html__('Title', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__('Title', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'material_angle_list_items_content',
            [
                'label'         => esc_html__('Content', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXTAREA,
                'default'       => esc_html__('Lorem ipsum dolor sit amet, consectetur adipisi cing elit, sed do eiusmod tempor incididunt ut abore et dolore magna', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'material_angle_list_items_number',
            [
                'label'         => esc_html__('List Number', ILPE_DOMAIN),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__('1', ILPE_DOMAIN),
            ]
        );

        $repeater->add_control(
            'material_angle_list_items_icon',
            [
                'type'          => Controls_Manager::ICONS,
                'default'       => [
                    'value'     => 'fas fa-leaf',
                    'library'   => 'fa-solid',
                ],
            ]
        );

        $repeater->add_control(
            'material_angle_title_color', [
                'label'         => esc_html__('Title Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
            ]
        );

        $repeater->add_control(
            'material_angle_content_color', [
                'label'         => esc_html__('Content Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
            ]
        );

        $repeater->add_control(
            'material_angle_content_bg_color', [
                'label'         => esc_html__('Content Background Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
            ]
        );

        $repeater->add_control(
            'material_angle_icon_color', [
                'label'         => esc_html__('Icon Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#ffffff',
            ]
        );

        $repeater->add_control(
            'material_angle_icon_bg_color_first', [
                'label'         => esc_html__('Icon Background Color 1', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#EC6161',
            ]
        );   

        $repeater->add_control(
            'material_angle_icon_bg_color_second', [
                'label'         => esc_html__('Icon Background Color 2', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#FF8181',
            ]
        );

        $repeater->add_control(
            'material_angle_list_no_color', [
                'label'         => esc_html__('List Number Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#000000',
            ]
        );

        $repeater->add_control(
            'list_items_number_separator_color', [
                'label'         => esc_html__('Separator Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#717B7F',          
            ]
        );

        $repeater->add_control(
			'material_angle_list_link',
			[
				'label' => esc_html__( 'Link', ILPE_DOMAIN ),
				'type' => Controls_Manager::URL,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'https://your-link.com', ILPE_DOMAIN ),
				'default' => [
					'url' => '#',
				],				
			]
		);

        $this->add_control(
            'material_angle_item_lists',
            [
                'label'         => esc_html__( 'List Items', ILPE_DOMAIN ),
                'type'          => Controls_Manager::REPEATER,
                'fields'        => $repeater->get_controls(),
                'render_type'   => 'template',
                'default'       => [
                    [
                        'material_angle_list_items_title'      => 'List One',
                    ],
                    [
                        'material_angle_list_items_title'      => 'List Two',
                        'material_angle_icon_bg_color_first'         => '#2DCEC6',
                        'material_angle_icon_bg_color_second'         => '#32DDD4',
                        'material_angle_list_items_icon'       => [
                            'value'     => 'fas fa-laugh',
                            'library'   => 'fa-solid',
                        ],
                    ],
                    [
                        'material_angle_list_items_title'      => 'List Three',
                        'material_angle_icon_bg_color_first'         => '#C56EE3',
                        'material_angle_icon_bg_color_second'         => '#DB87F7',
                        'material_angle_list_items_icon'       => [
                            'value'     => 'fas fa-paw',
                            'library'   => 'fa-solid',
                        ],
                    ],
                    [
                        'material_angle_list_items_title'      => 'List Four',
                        'material_angle_icon_bg_color_first'         => '#868BFF',
                        'material_angle_icon_bg_color_second'         => '#A8ADFF',
                        'material_angle_list_items_icon'       => [
                            'value'     => 'fas fa-magnet',
                            'library'   => 'fa-solid',
                        ],
                    ],
                ],
                'title_field'   => '{{{ material_angle_list_items_title }}}'
            ]
        );

        $this->end_controls_section();
        // End Item Lists Items Section

        // Start Box Style Control       
        $this->start_controls_section(
            'list_items_box_style', [
                'label'         => esc_html__('Box', ILPE_DOMAIN),
                'tab'           => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'list_items_box_column_direction', [
                'label'         => esc_html__('Direction', ILPE_DOMAIN),
                'type'          => Controls_Manager::SELECT,
                'options'       => [
                    'ltr' => esc_html__('LTR', ILPE_DOMAIN),
                    'rtl' => esc_html__('RTL', ILPE_DOMAIN),
                ],
                'condition'     => [
                    'item_lists_style!' => ['alternate-timeline-bullet-style', 'gradient-ordered-bullet-style', 'skew-bullet-style'],
                ],
                'default'       => 'ltr',
            ]
        );

        $this->add_control(
            'list_items_number_box_background_color', [
                'label'         => esc_html__('Background Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#F0F0F0',
                'selectors'     => [
                    '{{WRAPPER}} .ile-gradient-ordered-bullet-style .ile-content-box,
                    {{WRAPPER}} .ile-gradient-service-bullet-style .ile-content-box' => 'background: {{VALUE}};',
                ],
                'condition'     => [
                    'item_lists_style' => 'gradient-ordered-bullet-style',
                    'item_lists_style' => 'gradient-service-bullet-style',
                ],
            ]
        );

        $this->add_control(
            'list_items_number_box_background_hover_color', [
                'label'         => esc_html__('Background Hover Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'selectors'     => [
                    '{{WRAPPER}} .ile-gradient-ordered-bullet-style .ile-content-container:hover .ile-content-box'    => 'background: {{VALUE}};',
                ],
                'condition'     => [
                    'item_lists_style' => 'gradient-ordered-bullet-style',
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_box_margin', [
                'label'         => esc_html__('Box Margin', ILPE_DOMAIN),
                'type'          => Controls_Manager::DIMENSIONS,
                'size_units'    => ['px', '%'],
                'selectors'     => [
                    '{{WRAPPER}} .ile-gradient-ordered-bullet-style .ile-content-box' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'     => [
                    'item_lists_style' => 'gradient-ordered-bullet-style',
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_box_padding', [
                'label'         => esc_html__('Content Padding', ILPE_DOMAIN),
                'type'          => Controls_Manager::DIMENSIONS,
                'size_units'    => ['px', '%'],
                'selectors'     => [
                    '{{WRAPPER}} .ile-content-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_skew_box_margin_top', [
                'label'         => esc_html__('Margin', ILPE_DOMAIN),
                'type'          => Controls_Manager::DIMENSIONS,
                'size_units'    => ['px', '%'],
                'selectors'     => [
                    '{{WRAPPER}} .ile-skew-bullet-style .ile-content-box' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .ile-skew-bullet-style .ile-svg-container' => 'margin-top: {{TOP}}{{UNIT}}; margin-bottom: {{BOTTOM}}{{UNIT}};'
                ],
                'condition'     => [
                    'item_lists_style' => 'skew-bullet-style',
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_box_spacing', [
                'label'         => esc_html__('Space Between Box', ILPE_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'range'         => [
                    'px'    => [
                        'min'   => 0,
                        'max'   => 100,
                    ],
                ],
                'default'       => [ 'size'  => 20 ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-container-row,
                     {{WRAPPER}} .ile-shape-bullet-style .ile-content-box,
                     {{WRAPPER}} .ile-skew-bullet-style .ile-content-container,
                     {{WRAPPER}} .ile-gradient-service-bullet-style .ile-container-holder,
                     {{WRAPPER}} .ile-service-bullet-style .ile-container-holder,
                     {{WRAPPER}} .ile-gradient-service-bullet-style .ile-container-holder,
                     {{WRAPPER}} .ile-material-curve-bullet-style .ile-container-holder,
                     {{WRAPPER}} .ile-material-angle-bullet-style .ile-container-holder' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .ile-timeline-bullet-style .ile-container-holder,
                     {{WRAPPER}} .ile-alternate-timeline-bullet-style .ile-container-holder' => 'padding-bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition'     => [
                    'item_lists_style!' => 'gradient-ordered-bullet-style',
                ],
            ]
        );

        // $this->add_responsive_control(
        //     'list_items_skew_box_border_width', [
        //         'label'         => esc_html__('Border Width', ILPE_DOMAIN),
        //         'type'          => Controls_Manager::SLIDER,
        //         'range'         => [
        //             'px'    => [
        //                 'min'   => 0,
        //                 'max'   => 10,
        //             ],
        //         ],
        //         'default'       => [ 'size'  => 2 ],
        //         'selectors'     => [
        //             '{{WRAPPER}} .ile-skew-bullet-style .ile-content-box' => 'border: {{SIZE}}{{UNIT}} solid;',
        //         ],
        //         'condition'     => [
        //             'item_lists_style' => 'skew-bullet-style',
        //         ],
        //     ]
        // );

        // $this->add_responsive_control(
        //     'list_items_box_border_radius_new', [
        //         'label'         => esc_html__('Border Radius', ILPE_DOMAIN),
        //         'type'          => Controls_Manager::SLIDER,
        //         'range'         => [
        //             'px'    => [
        //                 'min'   => 0,
        //                 'max'   => 100,
        //             ],
        //         ],
        //         'condition'     => [
        //             'item_lists_style' => ['material-bullet-style', 'skew-bullet-style', 'gradient-service-bullet-style', 'service-bullet-style', 'material-curve-bullet-style', 'material-angle-bullet-style' ],
        //         ],
        //         'selectors'     => [
        //             '{{WRAPPER}} .ile-container-row,
        //             {{WRAPPER}} .ile-skew-bullet-style .ile-content-box,
        //             {{WRAPPER}} .ile-gradient-service-bullet-style .ile-content-box,
        //             {{WRAPPER}} .ile-service-bullet-style .ile-container-holder,
        //             {{WRAPPER}} .ile-service-bullet-style .ile-container-holder:before,
        //             {{WRAPPER}} .ile-material-curve-bullet-style .ile-container-holder,
        //             {{WRAPPER}} .ile-material-angle-bullet-style .ile-container-holder' => 'border-radius: {{SIZE}}{{UNIT}};',
        //         ],
        //         'separator'     => 'after',
        //     ]
        // );

        $this->add_control(
			'item_lists_border_options',
			[
				'label' => esc_html__('Border', ILPE_DOMAIN),
				'type'  => Controls_Manager::HEADING,
			]
		);

        $this->start_controls_tabs('item_lists_box_border_setting');

        $this->start_controls_tab(
            'item_lists_box_border_setting_normal',
            [
                'label' => esc_html__('Normal', ILPE_DOMAIN),
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(), [
                'name'          => 'item_lists_box_border',
                'selector'      => '{{WRAPPER}} .ile-container-row , {{WRAPPER}} .ile-content-box',
                'condition'     => [
                    'item_lists_style!' => [ 'service-bullet-style', 'material-curve-bullet-style', 'material-angle-bullet-style' ],
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(), [
                'name'          => 'item_lists_box_border_new',
                'selector'      => '{{WRAPPER}} .ile-service-bullet-style .ile-container-holder .ile-inner-container,
                                    {{WRAPPER}} .ile-material-curve-bullet-style .ile-container-holder,
                                    {{WRAPPER}} .ile-material-angle-bullet-style .ile-container-holder',
                'condition'     => [
                    'item_lists_style' => [ 'service-bullet-style', 'material-curve-bullet-style', 'material-angle-bullet-style' ],
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_box_border_radius', [
                'label'         => esc_html__('Border Radius', ILPE_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'range'         => [
                    'px'    => [
                        'min'   => 0,
                        'max'   => 100,
                    ],
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-container-row , {{WRAPPER}} .ile-content-box,
                     {{WRAPPER}} .ile-gradient-service-bullet-style .ile-content-box,
                     {{WRAPPER}} .ile-service-bullet-style .ile-container-holder .ile-inner-container,
                     {{WRAPPER}} .ile-service-bullet-style .ile-container-holder:before,
                     {{WRAPPER}} .ile-material-curve-bullet-style .ile-container-holder,
                     {{WRAPPER}} .ile-material-angle-bullet-style .ile-container-holder' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
		    Group_Control_Box_Shadow::get_type(), [
				'name'          => 'item_lists_box_shadow_normal',
				'label'         => esc_html__('Box Shadow', ILPE_DOMAIN),
				'selector'      => '{{WRAPPER}} .ile-container-row , {{WRAPPER}} .ile-content-box',
                'condition'     => [
                    'item_lists_style!' => [ 'service-bullet-style', 'material-curve-bullet-style', 'material-angle-bullet-style' ],
                ],
			]
		);

        $this->add_group_control(
		    Group_Control_Box_Shadow::get_type(), [
				'name'          => 'item_lists_box_shadow_normal_new',
				'label'         => esc_html__('Box Shadow', ILPE_DOMAIN),
				'selector'      => '{{WRAPPER}} .ile-material-curve-bullet-style .ile-container-holder,
                                    {{WRAPPER}} .ile-service-bullet-style .ile-inner-container,
                                    {{WRAPPER}} .ile-material-angle-bullet-style .ile-inner-container',
                'condition'     => [
                    'item_lists_style' => [ 'service-bullet-style', 'material-curve-bullet-style', 'material-angle-bullet-style' ],
                ],
			]
		);

        $this->end_controls_tab();

        $this->start_controls_tab(
            'item_lists_box_border_setting_hover',
            [
                'label' => esc_html__('Hover', ILPE_DOMAIN),
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(), [
                'name'          => 'item_lists_box_border_hover',
                'selector'      => '{{WRAPPER}} .ile-container-row:hover , {{WRAPPER}} .ile-content-box:hover',
                'condition'     => [
                    'item_lists_style!' => [ 'service-bullet-style', 'material-curve-bullet-style', 'material-angle-bullet-style' ],
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(), [
                'name'          => 'item_lists_box_border_hover_new',
                'selector'      => '{{WRAPPER}} .ile-service-bullet-style .ile-container-holder .ile-inner-container:hover, 
                                    {{WRAPPER}} .ile-material-curve-bullet-style .ile-container-holder:hover,
                                    {{WRAPPER}} .ile-material-angle-bullet-style .ile-container-holder:hover',
                'condition'     => [
                    'item_lists_style' => [ 'service-bullet-style', 'material-curve-bullet-style', 'material-angle-bullet-style' ],
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_box_border_radius_hover', [
                'label'         => esc_html__('Border Radius', ILPE_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'range'         => [
                    'px'    => [
                        'min'   => 0,
                        'max'   => 100,
                    ],
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-container-row:hover , {{WRAPPER}} .ile-content-box:hover,
                    {{WRAPPER}} .ile-gradient-service-bullet-style .ile-content-box:hover,
                    {{WRAPPER}} .ile-service-bullet-style .ile-container-holder .ile-inner-container:hover,
                    {{WRAPPER}} .ile-service-bullet-style .ile-container-holder:hover:before,
                    {{WRAPPER}} .ile-material-curve-bullet-style .ile-container-holder:hover,
                    {{WRAPPER}} .ile-material-angle-bullet-style .ile-container-holder:hover' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
		    Group_Control_Box_Shadow::get_type(), [
				'name'          => 'item_lists_box_shadow_hover',
				'label'         => esc_html__('Box Shadow', ILPE_DOMAIN),
				'selector'      => '{{WRAPPER}} .ile-container-row:hover , {{WRAPPER}} .ile-content-box:hover',
                'condition'     => [
                    'item_lists_style!' => [ 'service-bullet-style', 'material-curve-bullet-style', 'material-angle-bullet-style' ],
                ],
			]
		);

        $this->add_group_control(
		    Group_Control_Box_Shadow::get_type(), [
				'name'          => 'item_lists_box_shadow_hover_new',
				'label'         => esc_html__('Box Shadow', ILPE_DOMAIN),
				'selector'      => '{{WRAPPER}} .ile-material-curve-bullet-style .ile-container-holder:hover, {{WRAPPER}} .ile-service-bullet-style .ile-inner-container:hover, {{WRAPPER}} .ile-material-angle-bullet-style .ile-container-holder:hover',
                'condition'     => [
                    'item_lists_style' => [ 'service-bullet-style', 'material-curve-bullet-style', 'material-angle-bullet-style' ],
                ],
			]
		);

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_control(
			'hover_animation', [
				'label'         => esc_html__('Hover Animation', ILPE_DOMAIN),
				'type'          => Controls_Manager::HOVER_ANIMATION,
                'separator'     => 'before',
                'condition'     => [
                    'item_lists_style' => [ 'material-bullet-style', 'gradient-ordered-bullet-style', 'skew-bullet-style', 'service-bullet-style', 'gradient-service-bullet-style', 'material-curve-bullet-style'],
                ],
			]
		);

        $this->add_control(
            'shape_hover_animation', [
                'label'         => esc_html__('Hover Animation', ILPE_DOMAIN),
                'type'          => Controls_Manager::SELECT,
                'options'       => [
                    'float'                     => esc_html__('Float', ILPE_DOMAIN),
                    'sink'                      => esc_html__('Sink', ILPE_DOMAIN),
                    'bob'                       => esc_html__('Bob', ILPE_DOMAIN),
                    'hang'                      => esc_html__('Hang', ILPE_DOMAIN),
                    'skew'                      => esc_html__('Skew', ILPE_DOMAIN),
                    'skew-forward'              => esc_html__('Skew Forward', ILPE_DOMAIN),
                    'skew-backward'             => esc_html__('Skew Backward', ILPE_DOMAIN),
                    'wobble-vertical'           => esc_html__('Wobble Vertical', ILPE_DOMAIN),
                    'wobble-horizontal'         => esc_html__('Wobble Horizontal', ILPE_DOMAIN),
                    'wobble-to-bottom-right'    => esc_html__('Wobble To Bottom Right', ILPE_DOMAIN),
                    'wobble-to-top-right'       => esc_html__('Wobble To Top Right', ILPE_DOMAIN),
                    'wobble-top'                => esc_html__('Wobble Top', ILPE_DOMAIN),
                    'wobble-bottom'             => esc_html__('Wobble Bottom', ILPE_DOMAIN),
                    'wobble-skew'               => esc_html__('Wobble Skew', ILPE_DOMAIN),
                    'buzz'                      => esc_html__('Buzz', ILPE_DOMAIN),
                    'buzz-out'                  => esc_html__('Buzz Out', ILPE_DOMAIN),
                ],
                'default'       => 'float',
                'condition'     => [
                    'item_lists_style' => [ 'shape-bullet-style', 'timeline-bullet-style', 'alternate-timeline-bullet-style' ],
                ],
            ]
        );

        $this->end_controls_section();
        // End Box Style Control

        // Start Timeline Style Control
        $this->start_controls_section(
            'list_items_timeline_style', [
                'label'         => esc_html__('Timeline', ILPE_DOMAIN),
                'tab'           => Controls_Manager::TAB_STYLE,
                'condition'     => [
                    'item_lists_style' => [ 'timeline-bullet-style', 'alternate-timeline-bullet-style' ],
                ],
            ]
        );

        $this->add_control(
            'list_items_timeline_color', [
                'label'         => esc_html__('Timeline Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#d6d6d6',
                'selectors'     => [
                    '{{WRAPPER}} .ile-timeline-vertical,
                     {{WRAPPER}} .ile-timeline-horizontal'    => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_timeline_width', [
                'label'         => esc_html__('Timeline Width', ILPE_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'range'         => [
                    'px'    => [
                        'min'   => 0,
                        'max'   => 10,
                    ],
                ],
                'default'       => [ 'size'  => 2 ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-timeline-vertical'   => 'width: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .ile-timeline-horizontal' => 'height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .ile-timeline-right'      => 'margin-right: calc({{SIZE}}{{UNIT}} / 2);',
                    '{{WRAPPER}} .ile-timeline-left'       => 'margin-left: calc({{SIZE}}{{UNIT}} / 2);',
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_timeline_horizontal_width', [
                'label'         => esc_html__('Timeline Horizontal Width', ILPE_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'range'         => [
                    'px'    => [
                        'min'   => 0,
                        'max'   => 100,
                    ],
                ],
                'default'       => [ 'size'  => 50 ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-timeline-horizontal' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_timeline_horizontal_spacing', [
                'label'         => esc_html__('Timeline Horizontal Spacing', ILPE_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'range'         => [
                    'px'    => [
                        'min'   => 0,
                        'max'   => 100,
                    ],
                ],
                'default'       => [ 'size'  => 40 ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-timeline-horizontal' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
        // End Timeline Style Control       

        // Start Number Style Control
        $this->start_controls_section(
            'list_items_number_style', [
                'label'         => esc_html__('Number', ILPE_DOMAIN),
                'tab'           => Controls_Manager::TAB_STYLE,
                'condition'     => [
                    'item_lists_style' => ['gradient-ordered-bullet-style', 'gradient-service-bullet-style', 'material-angle-bullet-style', 'skew-bullet-style'],
                ],
            ]
        );

        $this->add_control(
            'list_items_number_color', [
                'label'         => esc_html__('Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#ffffff',
                'selectors'     => ['{{WRAPPER}} .ile-gradient-ordered-bullet-style li.ile-content-container::before, {{WRAPPER}} .ile-skew-bullet-style .ile-svg-container .ile-order-number' => 'color: {{VALUE}};'],  
                'condition'     => [
                    'item_lists_style!' => ['gradient-service-bullet-style', 'material-angle-bullet-style', 'skew-bullet-style'],
                ], 
            ]
        );

        $this->add_control(
            'list_items_number_hover_color', [
                'label'         => esc_html__('Hover Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#000000',
                'selectors'     => [
                    '{{WRAPPER}} .ile-gradient-ordered-bullet-style li.ile-content-container:hover::before' => 'color: {{VALUE}};',
                ],
                'condition'     => [
                    'item_lists_style!' => ['skew-bullet-style', 'gradient-service-bullet-style', 'material-angle-bullet-style'],
                ], 
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'          => 'typography_list_item_number',
                'selector'      => '{{WRAPPER}} .ile-gradient-ordered-bullet-style li.ile-content-container::before,
                                    {{WRAPPER}} .ile-skew-bullet-style .ile-svg-container .ile-order-number,
                                    {{WRAPPER}} .ile-gradient-service-bullet-style .ile-container-holder .ile-list-number,
                                    {{WRAPPER}} .ile-material-angle-bullet-style .ile-container-holder .ile-list-number',
            ]
        );

        $this->add_responsive_control(
            'list_items_number_box_size', [
                'label'         => esc_html__('Background Size', ILPE_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'range'         => [
                    'px'    => [
                        'min'   => 0,
                        'max'   => 200,
                    ],
                ],
                'default'       => [ 'size'  => 60 ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-gradient-ordered-bullet-style li.ile-content-container::before,
                     {{WRAPPER}} .ile-gradient-service-bullet-style .ile-container-holder .ile-list-number' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .ile-skew-bullet-style .ile-svg-container svg'    => 'width: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .ile-gradient-service-bullet-style'    => 'margin-top: calc({{SIZE}}{{UNIT}} / 2);'
                ],
                'condition'     => [
                    'item_lists_style!'  => 'material-angle-bullet-style',
                ],
            ]
        );

        $this->add_control(
            'list_items_number_box_alignment', [
                'label'         => esc_html__('Vertical Alignment', ILPE_DOMAIN),
                'type'          => Controls_Manager::SELECT,
                'options'       => [
                    'top'          => esc_html__('Top', ILPE_DOMAIN),
                    'middle'       => esc_html__('Middle', ILPE_DOMAIN),
                    'bottom'       => esc_html__('Botttom', ILPE_DOMAIN),
                ],
                'condition'     => [
                    'item_lists_style' => 'gradient-ordered-bullet-style',
                ],
                'default'       => 'top',
            ]
        );

        $this->start_controls_tabs(
            'item_lists_gradient_bg_setting',[
                'condition'     => [
                    'item_lists_style!' => ['skew-bullet-style', 'gradient-service-bullet-style', 'material-angle-bullet-style'],
                ],
            ]
        );

        $this->start_controls_tab(
            'item_lists_gradient_bg_setting_normal',
            [
                'label' => esc_html__('Normal', ILPE_DOMAIN),
            ]
        );

        $this->add_group_control(
			Group_Control_Background::get_type(), array(
				'name'          => 'list_items_number_background_color',
				'types'         => array( 'classic', 'gradient' ),
				'selector'      => '{{WRAPPER}} .ile-gradient-ordered-bullet-style li.ile-content-container::before',
			)
		);

        $this->end_controls_tab();

        $this->start_controls_tab(
            'item_lists_gradient_bg_setting_hover',
            [
                'label' => esc_html__('Hover', ILPE_DOMAIN),
            ]
        );

        $this->add_group_control(
			Group_Control_Background::get_type(), array(
				'name'          => 'list_items_number_background_hover_color',
				'types'         => array( 'classic', 'gradient' ),
				'selector'      => '{{WRAPPER}} .ile-gradient-ordered-bullet-style li.ile-content-container:hover::before',
                'condition'     => [
                    'item_lists_style!' => ['material-angle-bullet-style'],
                ],
			)
		);

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_control(
            'list_items_number_radius', [
                'label'         => esc_html__('Radius', ILPE_DOMAIN),
                'type'          => Controls_Manager::DIMENSIONS,
                'size_units'    => ['px', '%'],
                'selectors'     => [
                    '{{WRAPPER}} .ile-gradient-ordered-bullet-style li.ile-content-container::before,
                    {{WRAPPER}} .ile-gradient-service-bullet-style .ile-container-holder .ile-list-number' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'     => [
                    'item_lists_style!'  => 'material-angle-bullet-style',
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_number_margin', [
                'label'         => esc_html__('Number Margin', ILPE_DOMAIN),
                'type'          => Controls_Manager::DIMENSIONS,
                'size_units'    => ['px', '%'],
                'selectors'     => [
                    '{{WRAPPER}} .ile-material-angle-bullet-style .ile-list-number' => 'Margin-top: {{TOP}}{{UNIT}}; Margin-bottom: {{BOTTOM}}{{UNIT}}; padding-left: {{LEFT}}{{UNIT}}; padding-right: {{RIGHT}}{{UNIT}};',
                ],
                'condition'     => [
                    'item_lists_style'  => 'material-angle-bullet-style',
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_number_separator_width', [
                'label'         => esc_html__('Separator Width', ILPE_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'range'         => [
                    'px'    => [
                        'min'   => 0,
                        'max'   => 10,
                    ],
                ],
                'default'       => [ 'size'  => 1 ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-material-angle-bullet-style .ile-list-number:before' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition'     => [
                    'item_lists_style'  => 'material-angle-bullet-style',
                ],
            ]
        );

        $this->end_controls_section();
        // End Number Style Control

        // Start Icon Style Control 
        $this->start_controls_section(
            'list_items_icon_style', [
                'label'         => esc_html__('Icon', ILPE_DOMAIN),
                'tab'           => Controls_Manager::TAB_STYLE,
                'condition'     => [
                    'item_lists_style!' => 'gradient-ordered-bullet-style',
                ],
            ]
        );

        $this->add_control(
            'list_items_icon_box_alignment', [
                'label'         => esc_html__('Vertical Alignment', ILPE_DOMAIN),
                'type'          => Controls_Manager::SELECT,
                'options'       => [
                    'top'          => esc_html__('Top', ILPE_DOMAIN),
                    'middle'       => esc_html__('Middle', ILPE_DOMAIN),
                    'bottom'       => esc_html__('Botttom', ILPE_DOMAIN),
                ],
                'default'       => 'top',
                'condition'     => [
                    'item_lists_style' => 'skew-bullet-style',
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_icon_size', [
                'label'         => esc_html__('Icon Size', ILPE_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'range'         => [
                    'px'    => [
                        'min'   => 0,
                        'max'   => 100,
                    ],
                ],
                'default'       => [ 'size'  => 25 ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-icon' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .ile-shape-bullet-style svg:not(.ile-icon-shape), 
                     {{WRAPPER}} .ile-material-bullet-style svg,
                     {{WRAPPER}} .ile-timeline-bullet-style .ile-icon-box svg,
                     {{WRAPPER}} .ile-skew-bullet-style .ile-icon-box svg,
                     {{WRAPPER}} .ile-alternate-timeline-bullet-style .ile-icon-box svg,
                     {{WRAPPER}} .ile-gradient-service-bullet-style .ile-icon-box svg,
                     {{WRAPPER}} .ile-material-curve-bullet-style .ile-icon-box svg,
                     {{WRAPPER}} .ile-material-angle-bullet-style .ile-icon-box svg,
                     {{WRAPPER}} .ile-service-bullet-style .ile-icon-box svg' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'list_items_icon_color', [
                'label'         => esc_html__('Icon Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#00DAE6',
                'condition'     => [
                    'item_lists_style' => 'shape-bullet-style',
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-icon'    => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'list_items_icon_hover_color', [
                'label'         => esc_html__('Icon Hover Color ', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'condition'     => [
                    'item_lists_style' => 'shape-bullet-style',
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-container-holder:hover .ile-icon'    => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_icon_box_material_width', [
                'label'         => esc_html__('Icon Box Width', ILPE_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'range'         => [
                    'px'    => [
                        'min'   => 0,
                        'max'   => 200,
                    ],
                ],
                'default'       => [ 'size'  => 100 ],
                'condition'     => [
                    'item_lists_style'  => 'material-bullet-style',
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-icon-box'    => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_icon_box_width', [
                'label'         => esc_html__('Icon Box Size', ILPE_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'range'         => [
                    'px'    => [
                        'min'   => 0,
                        'max'   => 200,
                    ],
                ],
                'default'       => [ 'size'  => 80 ],
                'condition'     => [
                    'item_lists_style!' => 'material-bullet-style',
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-icon-box' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .ile-gradient-service-bullet-style .ile-icon-box:after' => 'width: calc({{SIZE}}{{UNIT}} / 10); height: calc({{SIZE}}{{UNIT}} / 10);',
                    '{{WRAPPER}} .ile-gradient-service-bullet-style.ltr' => 'margin-left: calc({{SIZE}}{{UNIT}} / 2);',
                    '{{WRAPPER}} .ile-gradient-service-bullet-style.rtl' => 'margin-right: calc({{SIZE}}{{UNIT}} / 2);',
                    '{{WRAPPER}} .ile-material-curve-bullet-style.ltr .ile-icon-box' => 'padding-right: calc({{SIZE}}{{UNIT}} / 4);',
                    '{{WRAPPER}} .ile-material-curve-bullet-style.rtl .ile-icon-box' => 'padding-left: calc({{SIZE}}{{UNIT}} / 4);',
                ],
            ]
        );

        $this->add_control(
            'list_items_icon_bg_color', [
                'label'         => esc_html__('Icon Background Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#ffffff',
                'condition'     => [
                    'item_lists_style' => 'shape-bullet-style',
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-icon-box svg path'    => 'fill: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'list_items_icon_bg_hover_color', [
                'label'         => esc_html__('Icon Background Hover Color ', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'condition'     => [
                    'item_lists_style' => 'shape-bullet-style',
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-container-holder:hover .ile-icon-box svg path'    => 'fill: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_icon_border_width', [
                'label'         => esc_html__('Icon Border Width', ILPE_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'range'         => [
                    'px'    => [
                        'min'   => 0,
                        'max'   => 10,
                    ],
                ],
                'default'       => [ 'size'  => 2 ],
                'condition'     => [
                    'item_lists_style' => 'shape-bullet-style',
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-icon-box svg.ile-icon-shape path' => 'stroke-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'list_items_icon_border_color', [
                'label'         => esc_html__('Icon Border Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#00DAE6',
                'condition'     => [
                    'item_lists_style' => 'shape-bullet-style',
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-icon-box svg.ile-icon-shape path'    => 'stroke: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'list_items_icon_border_hover_color', [
                'label'         => esc_html__('Icon Border Hover Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'condition'     => [
                    'item_lists_style' => 'shape-bullet-style',
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-container-holder:hover .ile-icon-box svg path'    => 'stroke: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_icon_line_width', [
                'label'         => esc_html__('Line Width', ILPE_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'range'         => [
                    'px'    => [
                        'min'   => 0,
                        'max'   => 10,
                    ],
                ],
                'default'       => [ 'size'  => 2 ],
                'condition'     => [
                    'item_lists_style' => 'shape-bullet-style',
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-shape-bullet-style .ile-line' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'list_items_icon_line_color', [
                'label'         => esc_html__('Line Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#000000',
                'condition'     => [
                    'item_lists_style' => 'shape-bullet-style',
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-shape-bullet-style .ile-line' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_icon_box_radius', [
                'label'         => esc_html__('Icon Box Radius', ILPE_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'range'         => [
                    'px'    => [
                        'min'   => 0,
                        'max'   => 200,
                    ],
                ],
                'default'       => [ 'size'  => 100 ],
                'condition'     => [
                    'item_lists_style' => [ 'timeline-bullet-style', 'alternate-timeline-bullet-style', 'skew-bullet-style' ],
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-timeline-bullet-style .ile-icon-box,
                     {{WRAPPER}} .ile-alternate-timeline-bullet-style .ile-icon-box,
                     {{WRAPPER}} .ile-skew-bullet-style .ile-icon-box' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_icon_radius', [
                'label'         => esc_html__('Icon Box Radius', ILPE_DOMAIN),
                'type'          => Controls_Manager::DIMENSIONS,
                'size_units'    => ['px', '%'],                
                'condition'     => [
                    'item_lists_style' => [ 'gradient-service-bullet-style' ],
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-gradient-service-bullet-style .ile-icon-box' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
        // End Icon Style Control

        // Start Image Style Control 
        $this->start_controls_section(
            'list_items_image_style', [
                'label'         => esc_html__('Image', ILPE_DOMAIN),
                'tab'           => Controls_Manager::TAB_STYLE,
                'condition'     => [
                    'item_lists_style' => ['material-bullet-style', 'timeline-bullet-style', 'alternate-timeline-bullet-style']
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_image_box_material_width', [
                'label'         => esc_html__('Image Width', ILPE_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'range'         => [
                    'px'    => [
                        'min'   => 0,
                        'max'   => 200,
                    ],
                ],
                'condition'     => [
                    'item_lists_style'  => 'material-bullet-style',
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-image'    => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_image_box_timeline_width', [
                'label'         => esc_html__('Image Width', ILPE_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'range'         => [
                    'px'    => [
                        'min'   => 0,
                        'max'   => 200,
                    ],
                ],
                'condition'     => [
                    'item_lists_style!'  => 'material-bullet-style',
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-image'    => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'list_items_image_box_material_radius', [
                'label'         => esc_html__('Radius', ILPE_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'range'         => [
                    'px'    => [
                        'min'   => 0,
                        'max'   => 200,
                    ],
                ],
                'default'       => [ 'size'  => 100 ],
                'condition'     => [
                    'item_lists_style'  => ['timeline-bullet-style', 'alternate-timeline-bullet-style'],
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-image'    => 'border-radius: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
        // End Image Style Control

        // Start Title Style Control       
        $this->start_controls_section(
            'list_items_title_style', [
                'label'         => esc_html__('Title', ILPE_DOMAIN),
                'tab'           => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'list_items_title_color', [
                'label'         => esc_html__('Title Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#000000',
                'condition'     => [
                    'item_lists_style!' => 'material-bullet-style',
                ],
                'selectors'     => [
                    '{{WRAPPER}} h2.ile-title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'list_items_title_hover_color', [
                'label'         => esc_html__('Title Hover Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'condition'     => [
                    'item_lists_style!' => ['material-bullet-style', 'gradient-ordered-bullet-style'],
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-container-holder:hover h2.ile-title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'list_items_gradient_title_hover_color', [
                'label'         => esc_html__('Title Hover Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'condition'     => [
                    'item_lists_style' => 'gradient-ordered-bullet-style',
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-container-holder .ile-content-container:hover h2.ile-title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'          => 'typography_list_item_title',
                'selector'      => '{{WRAPPER}} .ile-title',
            ]
        );

        $this->add_responsive_control(
            'list_item_title_spacing', [
                'label'         => esc_html__('Title Spacing', ILPE_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'range'         => [
                    'px'    => [
                        'min'   => 0,
                        'max'   => 100,
                    ],
                ],
                'default'       => [ 'size'  => 0 ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
        // End Title Style Control

        // Start Content Style Control       
        $this->start_controls_section(
            'list_items_content_style', [
                'label'         => esc_html__('Content', ILPE_DOMAIN),
                'tab'           => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'list_items_content_color', [
                'label'         => esc_html__('Content Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#999999',
                'condition'     => [
                    'item_lists_style!'     => 'material-bullet-style',
                ],
                'selectors'     => [
                    '{{WRAPPER}} p.ile-content'   => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'list_items_content_hover_color', [
                'label'         => esc_html__('Content Hover Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'condition'     => [
                    'item_lists_style!' => ['material-bullet-style', 'gradient-ordered-bullet-style'],
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-container-holder:hover p.ile-content'   => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'list_items_gradient_content_hover_color', [
                'label'         => esc_html__('Content Hover Color', ILPE_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'condition'     => [
                    'item_lists_style' => 'gradient-ordered-bullet-style',
                ],
                'selectors'     => [
                    '{{WRAPPER}} .ile-container-holder .ile-content-container:hover p.ile-content'   => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'          => 'typography_list_item_content',
                'selector'      => '{{WRAPPER}} .ile-content',
            ]
        );

        $this->end_controls_section();
        // End Content Style Control

    }

    /**
     * Render Item List Elements widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @access protected
     */
    protected function render() {

        $settings = $this->get_settings();
        $id = 'svg-' . $this->get_id();

        switch ($settings['item_lists_style']) {
            case 'material-bullet-style':
                include ILPE_PATH . 'include/item-lists-element/material-bullet-style.php'; // Material Bullets Style
                break;
            case 'shape-bullet-style':
                include ILPE_PATH . 'include/item-lists-element/shape-bullet-style.php'; // Shape Bullets Style
                break;
            case 'timeline-bullet-style':
                include ILPE_PATH . 'include/item-lists-element/timeline-bullet-style.php'; // Timeline Bullets Style
                break;
            case 'alternate-timeline-bullet-style':
                include ILPE_PATH . 'include/item-lists-element/alternate-timeline-bullet-style.php'; // Alternate Timeline Bullets Style
                break;
            case 'gradient-ordered-bullet-style':
                include ILPE_PATH . 'include/item-lists-element/gradient-ordered-bullet-style.php'; // Gradient Ordered Bullets Style
                break;
            case 'skew-bullet-style':
                include ILPE_PATH . 'include/item-lists-element/skew-bullet-style.php'; // Skew Bullets Style
                break;
            case 'service-bullet-style':
                include ILPE_PATH . 'include/item-lists-element/service-bullet-style.php'; // Service Bullet Style
                break;
            case 'gradient-service-bullet-style':
                include ILPE_PATH . 'include/item-lists-element/gradient-service-bullet-style.php'; // Gradient Service Bullet Style
                break;
            case 'material-curve-bullet-style':
                include ILPE_PATH . 'include/item-lists-element/material-curve-bullet-style.php'; // Material Curve Bullet Style
                break;
            case 'material-angle-bullet-style':
                include ILPE_PATH . 'include/item-lists-element/material-angle-bullet-style.php'; // Material Angle Bullet Style
                break;
            default:
                include ILPE_PATH . 'include/item-lists-element/material-bullet-style.php'; // Default
                break;
        }
    }

}

Plugin::instance()->widgets_manager->register_widget_type(new Item_Lists_Pro_Elementor_Widget());